@@ -35,7 +35,7 @@ module Stomp
     #   stomp://login:passcode@host:port
     #   stomp://login:passcode@host.domain.tld:port
     #
-    def initialize(login = '', passcode = '', host = 'localhost', port = 61613, reliable = false)
+    def initialize(login = '', passcode = '', host = 'localhost', port = 61613, reliable = false, autoflush = false)
 
       # Parse stomp:// URL's or set params
       if login.is_a?(Hash)
@@ -49,7 +49,6 @@ module Stomp
         @port = first_host[:port] || Connection::default_port(first_host[:ssl])
         
         @reliable = true
-        
       elsif login =~ /^stomp:\/\/#{url_regex}/ # e.g. stomp://login:passcode@host:port or stomp://host:port
         @login = $2 || ""
         @passcode = $3 || ""
@@ -94,6 +93,7 @@ module Stomp
         @connection = Connection.new(@parameters)
       else
         @connection = Connection.new(@login, @passcode, @host, @port, @reliable)
+        @connection.autoflush = autoflush
       end
       
       start_listeners
@@ -265,6 +265,40 @@ module Stomp
       @connection.uuid()
     end
 
+    # Retrieve heartbeat send interval
+    def hbsend_interval
+      @connection.hbsend_interval
+    end
+
+    # Retrieve heartbeat receive interval
+    def hbrecv_interval
+      @connection.hbrecv_interval
+    end
+
+    # Retrieve heartbeat send count
+    def hbsend_count
+      @connection.hbsend_count
+    end
+
+    # Retrieve heartbeat receive count
+    def hbrecv_count
+      @connection.hbrecv_count
+    end
+
+    # Poll for asynchronous messages issued by broker.
+    # Return nil of no message available, else the message
+    def poll
+      @connection.poll
+    end
+
+    def autoflush=(af)
+      @connection.autoflush = af
+    end
+
+    def autoflush
+      @connection.autoflush
+    end
+
     private
       # Set a subscription id in the headers hash if one does not already exist.
       # For simplicities sake, all subscriptions have a subscription ID.
