@@ -10,12 +10,13 @@ module Stomp
   # Low level connection which maps commands and supports
   # synchronous receives
   class Connection
-    attr_reader :connection_frame
-    attr_reader :disconnect_receipt
-    attr_reader :protocol
-    attr_reader :session
-    attr_reader :hb_received # Heartbeat received on time
-    attr_reader :hb_sent # Heartbeat sent successfully
+    attr_reader   :connection_frame
+    attr_reader   :disconnect_receipt
+    attr_reader   :protocol
+    attr_reader   :session
+    attr_reader   :hb_received # Heartbeat received on time
+    attr_reader   :hb_sent # Heartbeat sent successfully
+    attr_accessor :autoflush
     #alias :obj_send :send
 
     def self.default_port(ssl)
@@ -87,6 +88,7 @@ module Stomp
         @parse_timeout = 5		# To override, use hashed parameters
         @connect_timeout = 0	# To override, use hashed parameters
         @logger = nil     		# To override, use hashed parameters
+        @autoflush = false    # To override, use hashed parameters or setter
         warn "login looks like a URL, do you have the correct parameters?" if @login =~ /:\/\//
       end
 
@@ -112,6 +114,7 @@ module Stomp
       @parse_timeout =  @parameters[:parse_timeout]
       @connect_timeout =  @parameters[:connect_timeout]
       @logger =  @parameters[:logger]
+      @autoflush = @parameters[:autoflush]
       #sets the first host to connect
       change_host
     end
@@ -170,7 +173,6 @@ module Stomp
 
     def refine_params(params)
       params = params.uncamelize_and_symbolize_keys
-
       default_params = {
         :connect_headers => {},
         :reliable => true,
@@ -184,11 +186,15 @@ module Stomp
         :backup => false,
         :connect_timeout => 0,
         # Parse Timeout
-        :parse_timeout => 5
+        :parse_timeout => 5,
+        :dmh => false,
       }
 
-      default_params.merge(params)
-
+      res_params = default_params.merge(params)
+      if res_params[:dmh]
+        res_params = _expand_hosts(res_params)
+      end
+      return res_params
     end
 
     def change_host
@@ -485,11 +491,69 @@ module Stomp
       rs
     end
 
+    # Retrieve heartbeat send interval
+    def hbsend_interval
+      return 0 unless @hbsend_interval
+      @hbsend_interval / 1000.0 # ms
+    end
+
+    # Retrieve heartbeat receive interval
+    def hbrecv_interval
+      return 0 unless @hbrecv_interval
+      @hbrecv_interval / 1000.0 # ms
+    end
+
+    # Retrieve heartbeat send count
+    def hbsend_count
+      return 0 unless @hbsend_count
+      @hbsend_count
+    end
+
+    # Retrieve heartbeat receive count
+    def hbrecv_count
+      return 0 unless @hbrecv_count
+      @hbrecv_count
+    end
+
     private
 
+      def _expand_hosts(hash)
+        new_hash = hash.clone
+        new_hash[:hosts_cloned] = hash[:hosts].clone
+        new_hash[:hosts] = []
+        #
+        hash[:hosts].each do |host_parms|
+          ai = Socket.getaddrinfo(host_parms[:host], nil, nil, Socket::SOCK_STREAM)
+          next if ai.nil? || ai.size == 0
+          info6 = ai.detect {|info| info[4] == Socket::AF_INET6}
+          info4 = ai.detect {|info| info[4] == Socket::AF_INET}
+          if info6
+            new_hostp = host_parms.clone
+            new_hostp[:host] = info6[3]
+            new_hash[:hosts] << new_hostp
+          end
+          if info4
+            new_hostp = host_parms.clone
+            new_hostp[:host] = info4[3]
+            new_hash[:hosts] << new_hostp
+          end
+        end
+        return new_hash
+      end
+
       def _receive( read_socket )
         @read_semaphore.synchronize do
-          line = read_socket.gets
+          line = ''
+          if @protocol == Stomp::SPL_10 || (@protocol >= Stomp::SPL_11 && !@hbr)
+            line = read_socket.gets # The old way
+          else # We are >= 1.1 and receiving heartbeats.
+            while true
+              line = read_socket.gets # Data from wire
+              break unless line == "\n"
+              line = ''
+              @lr = Time.now.to_f
+            end
+          end
           return nil if line.nil?
           # If the reading hangs for more than X seconds, abort the parsing process.
           # X defaults to 5.  Override allowed in connection hash parameters.
@@ -596,8 +660,8 @@ module Stomp
           # and ActiveMQ will interpret the message as a TextMessage.
           # For more information refer to http://juretta.com/log/2009/05/24/activemq-jms-stomp/
           # Lets send this header in the message, so it can maintain state when using unreceive
-          headers['content-length'] = "#{body_length_bytes}" unless headers[:suppress_content_length]
-          headers['content-type'] = "text/plain; charset=UTF-8" unless headers['content-type']
+          headers[:'content-length'] = "#{body_length_bytes}" unless headers[:suppress_content_length]
+          headers[:'content-type'] = "text/plain; charset=UTF-8" unless headers[:'content-type']
           used_socket.puts command
           headers.each do |k,v|
             if v.is_a?(Array)
@@ -611,6 +675,7 @@ module Stomp
           used_socket.puts
           used_socket.write body
           used_socket.write "\0"
+          used_socket.flush if autoflush
 
           if @protocol >= Stomp::SPL_11
             @ls = Time.now.to_f if @hbs
@@ -684,10 +749,10 @@ module Stomp
             if @ssl.cert_file # Any check will do here
               raise Stomp::Error::SSLNoCertFileError if !File::exists?(@ssl.cert_file)
               raise Stomp::Error::SSLUnreadableCertFileError if !File::readable?(@ssl.cert_file)
-              ctx.cert = OpenSSL::X509::Certificate.new(File.open(@ssl.cert_file))
+              ctx.cert = OpenSSL::X509::Certificate.new(File.read(@ssl.cert_file))
               raise Stomp::Error::SSLNoKeyFileError if !File::exists?(@ssl.key_file)
               raise Stomp::Error::SSLUnreadableKeyFileError if !File::readable?(@ssl.key_file)
-              ctx.key  = OpenSSL::PKey::RSA.new(File.open(@ssl.key_file))
+              ctx.key  = OpenSSL::PKey::RSA.new(File.read(@ssl.key_file), @ssl.key_password)
             end
 
             # Cipher list
@@ -815,10 +880,16 @@ module Stomp
       def _post_connect
         return unless (@connect_headers[:"accept-version"] && @connect_headers[:host])
         return if @connection_frame.command == Stomp::CMD_ERROR
+        # We are CONNECTed
         cfh = @connection_frame.headers.symbolize_keys
         @protocol = cfh[:version]
-        # Should not happen, but check anyway
-        raise Stomp::Error::UnsupportedProtocolError unless Stomp::SUPPORTED.index(@protocol)
+        if @protocol
+          # Should not happen, but check anyway
+          raise Stomp::Error::UnsupportedProtocolError unless Stomp::SUPPORTED.index(@protocol)
+        else # CONNECTed to a 1.0 server that does not return *any* 1.1 type headers
+          @protocol = Stomp::SPL_10 # reset
+          return
+        end 
         # Heartbeats
         return unless @connect_headers[:"heart-beat"]
         _init_heartbeats()
@@ -837,7 +908,9 @@ module Stomp
         #
         @cx = @cy = @sx = @sy = 0, # Variable names as in spec
         #
-        @sti = @rti = 0.0 # Send/Receive ticker interval.
+        @hbsend_interval = @hbrecv_interval = 0.0 # Send/Receive ticker interval.
+        #
+        @hbsend_count = @hbrecv_count = 0 # Send/Receive ticker counts.
         #
         @ls = @lr = -1.0 # Last send/receive time (from Time.now.to_f)
         #
@@ -866,7 +939,7 @@ module Stomp
         # If sending
         if @hbs
           sm = @cx >= @sy ? @cx : @sy # ticker interval, ms
-          @sti = 1000.0 * sm # ticker interval, μs
+          @hbsend_interval = 1000.0 * sm # ticker interval, μs
           @ls = Time.now.to_f # best guess at start
           _start_send_ticker
         end
@@ -874,7 +947,7 @@ module Stomp
         # If receiving
         if @hbr
           rm = @sx >= @cy ? @sx : @cy # ticker interval, ms
-          @rti = 1000.0 * rm # ticker interval, μs
+          @hbrecv_interval = 1000.0 * rm # ticker interval, μs
           @lr = Time.now.to_f # best guess at start
           _start_receive_ticker
         end
@@ -882,7 +955,7 @@ module Stomp
       end
 
       def _start_send_ticker
-        sleeptime = @sti / 1000000.0 # Sleep time secs
+        sleeptime = @hbsend_interval / 1000000.0 # Sleep time secs
         @st = Thread.new {
           while true do
             sleep sleeptime
@@ -891,7 +964,7 @@ module Stomp
               @logger.on_hbfire(log_params, "send_fire", curt)
             end
             delta = curt - @ls
-            if delta > (@sti - (@sti/5.0)) / 1000000.0 # Be tolerant (minus)
+            if delta > (@hbsend_interval - (@hbsend_interval/5.0)) / 1000000.0 # Be tolerant (minus)
               if @logger && @logger.respond_to?(:on_hbfire)
                 @logger.on_hbfire(log_params, "send_heartbeat", curt)
               end
@@ -901,10 +974,11 @@ module Stomp
                   @socket.puts
                   @ls = curt # Update last send
                   @hb_sent = true # Reset if necessary
+                  @hbsend_count += 1
                 rescue Exception => sendex
                   @hb_sent = false # Set the warning flag
                   if @logger && @logger.respond_to?(:on_hbwrite_fail)
-                    @logger.on_hbwrite_fail(log_params, {"ticker_interval" => @sti,
+                    @logger.on_hbwrite_fail(log_params, {"ticker_interval" => @hbsend_interval,
                       "exception" => sendex})
                   end
                   raise # Re-raise.  What else could be done here?
@@ -917,7 +991,7 @@ module Stomp
       end
 
       def _start_receive_ticker
-        sleeptime = @rti / 1000000.0 # Sleep time secs
+        sleeptime = @hbrecv_interval / 1000000.0 # Sleep time secs
         @rt = Thread.new {
           while true do
             sleep sleeptime
@@ -926,7 +1000,7 @@ module Stomp
               @logger.on_hbfire(log_params, "receive_fire", curt)
             end
             delta = curt - @lr
-            if delta > ((@rti + (@rti/5.0)) / 1000000.0) # Be tolerant (plus)
+            if delta > ((@hbrecv_interval + (@hbrecv_interval/5.0)) / 1000000.0) # Be tolerant (plus)
               if @logger && @logger.respond_to?(:on_hbfire)
                 @logger.on_hbfire(log_params, "receive_heartbeat", curt)
               end
@@ -942,11 +1016,12 @@ module Stomp
                   @socket.ungetc(last_char)
                 end
                 @read_semaphore.unlock
+                @hbrecv_count += 1
               else
                 # Shrug.  Have not received one.  Just set warning flag.
                 @hb_received = false
                 if @logger && @logger.respond_to?(:on_hbread_fail)
-                  @logger.on_hbread_fail(log_params, {"ticker_interval" => @rti})
+                  @logger.on_hbread_fail(log_params, {"ticker_interval" => @hbrecv_interval})
                 end
               end
             else
